==> qtjambi-qt3drender-6.2.3-sources.jar: io/qt/qt3d/render/QPolygonOffset.java <==
package io.qt.qt3d.render;


/**
 * <p>Sets the scale and steps to calculate depth values for polygon offsets</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html">Qt3DRender::QPolygonOffset</a></p>
 */
public class QPolygonOffset extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPolygonOffset.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::depthStepsChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="depthSteps")
    public final Signal1<@io.qt.QtPrimitiveType Float> depthStepsChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::scaleFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="scaleFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> scaleFactorChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QPolygonOffset(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QPolygonOffset() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#QPolygonOffset">Qt3DRender::QPolygonOffset::QPolygonOffset(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QPolygonOffset(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPolygonOffset instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::depthSteps()const</a></p>
     */
    @io.qt.QtPropertyReader(name="depthSteps")
    @io.qt.QtUninvokable
    public final float depthSteps(){
        return depthSteps_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float depthSteps_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::scaleFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scaleFactor")
    @io.qt.QtUninvokable
    public final float scaleFactor(){
        return scaleFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float scaleFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::setDepthSteps(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="depthSteps")
    public final void setDepthSteps(float depthSteps){
        setDepthSteps_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), depthSteps);
    }
    
    private native void setDepthSteps_native_float(long __this__nativeId, float depthSteps);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::setScaleFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="scaleFactor")
    public final void setScaleFactor(float scaleFactor){
        setScaleFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), scaleFactor);
    }
    
    private native void setScaleFactor_native_float(long __this__nativeId, float scaleFactor);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPolygonOffset(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPolygonOffset(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPolygonOffset instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.0-sources.jar: io/qt/qt3d/render/QPolygonOffset.java <==
package io.qt.qt3d.render;


/**
 * <p>Sets the scale and steps to calculate depth values for polygon offsets</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html">Qt3DRender::QPolygonOffset</a></p>
 */
public class QPolygonOffset extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPolygonOffset.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::depthStepsChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="depthSteps")
    public final Signal1<@io.qt.QtPrimitiveType Float> depthStepsChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::scaleFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="scaleFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> scaleFactorChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QPolygonOffset(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QPolygonOffset() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#QPolygonOffset">Qt3DRender::QPolygonOffset::QPolygonOffset(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QPolygonOffset(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPolygonOffset instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::depthSteps()const</a></p>
     */
    @io.qt.QtPropertyReader(name="depthSteps")
    @io.qt.QtUninvokable
    public final float depthSteps(){
        return depthSteps_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float depthSteps_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::scaleFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scaleFactor")
    @io.qt.QtUninvokable
    public final float scaleFactor(){
        return scaleFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float scaleFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#depthSteps-prop">Qt3DRender::QPolygonOffset::setDepthSteps(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="depthSteps")
    public final void setDepthSteps(float depthSteps){
        setDepthSteps_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), depthSteps);
    }
    
    private native void setDepthSteps_native_float(long __this__nativeId, float depthSteps);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qpolygonoffset.html#scaleFactor-prop">Qt3DRender::QPolygonOffset::setScaleFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="scaleFactor")
    public final void setScaleFactor(float scaleFactor){
        setScaleFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), scaleFactor);
    }
    
    private native void setScaleFactor_native_float(long __this__nativeId, float scaleFactor);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPolygonOffset(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPolygonOffset(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPolygonOffset instance, QDeclarativeConstructor constructor);
    
}
